@@ -1,5 +1,5 @@
 /**
- * Copyright 2012 JogAmp Community. All rights reserved.
+ * Copyright 2012-2023 JogAmp Community. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without modification, are
  * permitted provided that the following conditions are met:
@@ -39,6 +39,7 @@ import com.jogamp.opengl.GLProfile;
 import com.jogamp.common.ExceptionUtils;
 import com.jogamp.common.os.DynamicLibraryBundle;
 import com.jogamp.common.os.DynamicLibraryBundleInfo;
+import com.jogamp.common.os.NativeLibrary;
 import com.jogamp.common.util.RunnableExecutor;
 import com.jogamp.common.util.SecurityUtil;
 import com.jogamp.common.util.VersionNumber;
@@ -51,14 +52,15 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
 
     private static final List<String> glueLibNames = new ArrayList<String>(); // none
 
-    private static final int symbolCount = 59;
+    private static final int symbolCount = 67;
     private static final String[] symbolNames = {
          "avutil_version",
          "avformat_version",
          "avcodec_version",
          "avdevice_version",   // (opt)
          "swresample_version",
-         /* 5 */
+         "swscale_version", // (opt)
+         /* 6 */
 
          // libavcodec
          "avcodec_close",
@@ -79,7 +81,9 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "av_packet_unref",
          "avcodec_send_packet",       // 57
          "avcodec_receive_frame",     // 57
-         /* +18 = 23 */
+         "avcodec_decode_subtitle2",  // 52.23.0
+         "avsubtitle_free",           // 52.82.0
+         /* +20 = 26 */
 
          // libavutil
          "av_pix_fmt_desc_get",       // >= lavu 51.45
@@ -90,6 +94,7 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "av_samples_get_buffer_size",
          "av_get_bytes_per_sample",   // 51.4.0
          "av_opt_set_int",            // 51.12.0
+         "av_dict_iterate",           // 57.42.100
          "av_dict_get",
          "av_dict_count",             // 54.* (opt)
          "av_dict_set",
@@ -98,7 +103,7 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "av_channel_layout_uninit", // >= 59 (opt)
          "av_channel_layout_describe", // >= 59 (opt)
          "av_opt_set_chlayout",        // >= 59
-         /* +16 = 39 */
+         /* +17 = 43 */
 
          // libavformat
          "avformat_alloc_context",
@@ -115,11 +120,11 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "avformat_network_init",     // 53.13.0   (opt)
          "avformat_network_deinit",   // 53.13.0   (opt)
          "avformat_find_stream_info", // 53.3.0    (opt)
-         /* +14 = 53 */
+         /* +14 = 57 */
 
          // libavdevice
          "avdevice_register_all",     // supported in all versions (opt)
-         /* +1  = 54 */
+         /* +1  = 58 */
 
          // libswresample
          "av_opt_set_sample_fmt",     // actually lavu .. but exist only w/ swresample!
@@ -127,7 +132,14 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "swr_init",
          "swr_free",
          "swr_convert",
-         /* +5  = 59 */
+         "swr_get_out_samples",
+         /* +6  = 64 */
+
+         // libswscale
+         "sws_getCachedContext",      // opt
+         "sws_scale",                 // opt
+         "sws_freeContext",           // opt
+         /* +3  = 67 */
     };
 
     // optional symbol names
@@ -136,6 +148,7 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "av_dict_count",             // 54.*   (opt)
 
          // libavutil
+         "av_dict_iterate",           // >= 57.42.100
          "av_channel_layout_default", // >= 59 (opt)
          "av_channel_layout_uninit", // >= 59 (opt)
          "av_channel_layout_describe", // >= 59 (opt)
@@ -151,25 +164,57 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
          "swr_init",
          "swr_free",
          "swr_convert",
+         "swr_get_out_samples",
+
+         // libswscale
+         "swscale_version",           // opt
+         "sws_getCachedContext",      // opt
+         "sws_scale",                 // opt
+         "sws_freeContext",           // opt
     };
 
-    private static final int LIB_COUNT = 5;
+    /** 6: util, format, codec, device, swresample, swscale */
+    private static final int LIB_COUNT = 6;
     private static final int LIB_IDX_UTI = 0;
     private static final int LIB_IDX_FMT = 1;
     private static final int LIB_IDX_COD = 2;
     private static final int LIB_IDX_DEV = 3;
     private static final int LIB_IDX_SWR = 4;
+    private static final int LIB_IDX_SWS = 5;
 
     /** util, format, codec, device, swresample */
     private static final boolean[] libLoaded = new boolean[LIB_COUNT];
     private static final long[] symbolAddr = new long[symbolCount];
     private static final boolean ready;
     private static final boolean libsCFUSLoaded;
-    static final VersionNumber avCodecVersion;
-    static final VersionNumber avFormatVersion;
-    static final VersionNumber avUtilVersion;
-    static final VersionNumber avDeviceVersion;
-    static final VersionNumber swResampleVersion;
+    public static class VersionedLib {
+        public final NativeLibrary lib;
+        public final VersionNumber version;
+        public VersionedLib(final NativeLibrary lib, final VersionNumber version) {
+            this.lib = lib;
+            this.version = version;
+        }
+        @Override
+        public String toString() {
+            final String ls;
+            if( null != lib ) {
+                if( null != lib.getNativeLibraryPath() ) {
+                    ls = "nlp '"+lib.getNativeLibraryPath()+"'";
+                } else {
+                    ls = "vlp '"+lib.getLibraryPath()+"'";
+                }
+            } else {
+                ls = "n/a";
+            }
+            return ls+", "+version;
+        }
+    }
+    static final VersionedLib avUtil;
+    static final VersionedLib avFormat;
+    static final VersionedLib avCodec;
+    static final VersionedLib avDevice;
+    static final VersionedLib swResample;
+    static final VersionedLib swScale;
     private static final FFMPEGNatives natives;
 
     private static final PrivilegedAction<DynamicLibraryBundle> privInitSymbolsAction = new PrivilegedAction<DynamicLibraryBundle>() {
@@ -196,10 +241,10 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
         } };
 
     /**
-     * @param versions 5: util, format, codec, swresample
+     * @param versions 6: util, format, codec, device, swresample, swscale
      * @return
      */
-    private static final boolean initSymbols(final VersionNumber[] versions) {
+    private static final boolean initSymbols(final VersionNumber[] versions, final List<NativeLibrary> nativeLibs) {
         for(int i=0; i<libLoaded.length; i++) {
             libLoaded[i] = false;
         }
@@ -211,6 +256,8 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
         if( null == dl ) {
             return false;
         }
+        nativeLibs.clear();
+        nativeLibs.addAll(dl.getToolLibraries());
 
         // optional symbol name set
         final Set<String> optionalSymbolNameSet = new HashSet<String>();
@@ -239,7 +286,11 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
             versions[LIB_IDX_DEV] = new VersionNumber(0, 0, 0);
         }
         versions[LIB_IDX_SWR] = FFMPEGStaticNatives.getAVVersion(FFMPEGStaticNatives.getAvVersion0(symbolAddr[LIB_IDX_SWR]));
-
+        if( 0 != symbolAddr[LIB_IDX_SWS] ) {
+            versions[LIB_IDX_SWS] = FFMPEGStaticNatives.getAVVersion(FFMPEGStaticNatives.getAvVersion0(symbolAddr[LIB_IDX_SWS]));
+        } else {
+            versions[LIB_IDX_SWS] = new VersionNumber(0, 0, 0);
+        }
         return res;
     }
 
@@ -248,19 +299,21 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
         GLProfile.initSingleton();
 
         boolean _ready = false;
-        /** util, format, codec, swresample */
+        /** 6: util, format, codec, device, swresample, swscale */
         final VersionNumber[] _versions = new VersionNumber[LIB_COUNT];
+        final List<NativeLibrary> _nativeLibs = new ArrayList<NativeLibrary>();
         try {
-            _ready = initSymbols(_versions);
+            _ready = initSymbols(_versions, _nativeLibs);
         } catch (final Throwable t) {
             ExceptionUtils.dumpThrowable("", t);
         }
         libsCFUSLoaded = libLoaded[LIB_IDX_COD] && libLoaded[LIB_IDX_FMT] && libLoaded[LIB_IDX_UTI] && libLoaded[LIB_IDX_SWR];
-        avUtilVersion = _versions[LIB_IDX_UTI];
-        avFormatVersion = _versions[LIB_IDX_FMT];
-        avCodecVersion = _versions[LIB_IDX_COD];
-        avDeviceVersion = _versions[LIB_IDX_DEV];
-        swResampleVersion = _versions[LIB_IDX_SWR];
+        avUtil = new VersionedLib(_nativeLibs.get(LIB_IDX_UTI), _versions[LIB_IDX_UTI]);
+        avFormat = new VersionedLib(_nativeLibs.get(LIB_IDX_FMT), _versions[LIB_IDX_FMT]);
+        avCodec = new VersionedLib(_nativeLibs.get(LIB_IDX_COD), _versions[LIB_IDX_COD]);
+        avDevice = new VersionedLib(_nativeLibs.get(LIB_IDX_DEV), _versions[LIB_IDX_DEV]);
+        swResample = new VersionedLib(_nativeLibs.get(LIB_IDX_SWR), _versions[LIB_IDX_SWR]);
+        swScale = new VersionedLib(_nativeLibs.get(LIB_IDX_SWS), _versions[LIB_IDX_SWS]);
         if(!libsCFUSLoaded) {
             String missing = "";
             if( !libLoaded[LIB_IDX_COD] ) {
@@ -283,18 +336,25 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
             natives = null;
             ready = false;
         } else {
-            final int avCodecMajor = avCodecVersion.getMajor();
-            final int avFormatMajor = avFormatVersion.getMajor();
-            final int avUtilMajor = avUtilVersion.getMajor();
-            final int avDeviceMajor = avDeviceVersion.getMajor();
-            final int swResampleMajor = swResampleVersion.getMajor();
-            if( avCodecMajor == 58 && avFormatMajor == 58 && ( avDeviceMajor == 58 || avDeviceMajor == 0 ) && avUtilMajor == 56 && swResampleMajor == 3) {
+            final int avUtilMajor = avUtil.version.getMajor();
+            final int avFormatMajor = avFormat.version.getMajor();
+            final int avCodecMajor = avCodec.version.getMajor();
+            final int avDeviceMajor = avDevice.version.getMajor();
+            final int swResampleMajor = swResample.version.getMajor();
+            final int swScaleMajor = swScale.version.getMajor();
+            if( avCodecMajor == 58 && avFormatMajor == 58 && ( avDeviceMajor == 58 || avDeviceMajor == 0 ) && avUtilMajor == 56 &&
+                swResampleMajor == 3 && ( swScaleMajor == 5 || swScaleMajor == 0 ) )
+            {
                 // Exact match: ffmpeg 4.x.y
                 natives = new FFMPEGv0400Natives();
-            } else if( avCodecMajor == 59 && avFormatMajor == 59 && ( avDeviceMajor == 59 || avDeviceMajor == 0 ) && avUtilMajor == 57 && swResampleMajor == 4) {
+            } else if( avCodecMajor == 59 && avFormatMajor == 59 && ( avDeviceMajor == 59 || avDeviceMajor == 0 ) && avUtilMajor == 57 &&
+                       swResampleMajor == 4 && ( swScaleMajor == 6 || swScaleMajor == 0 ) )
+            {
                 // Exact match: ffmpeg 5.x.y
                 natives = new FFMPEGv0500Natives();
-            } else if( avCodecMajor == 60 && avFormatMajor == 60 && ( avDeviceMajor == 60 || avDeviceMajor == 0 ) && avUtilMajor == 58 && swResampleMajor == 4) {
+            } else if( avCodecMajor == 60 && avFormatMajor == 60 && ( avDeviceMajor == 60 || avDeviceMajor == 0 ) && avUtilMajor == 58 &&
+                       swResampleMajor == 4 && ( swScaleMajor == 7 || swScaleMajor == 0 ) )
+            {
                 // Exact match: ffmpeg 6.x.y
                 natives = new FFMPEGv0600Natives();
             } else {
@@ -318,6 +378,7 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
     static boolean libsLoaded() { return libsCFUSLoaded; }
     static boolean avDeviceLoaded() { return libLoaded[LIB_IDX_DEV]; }
     static boolean swResampleLoaded() { return libLoaded[LIB_IDX_SWR]; }
+    static boolean swScaleLoaded() { return libLoaded[LIB_IDX_SWS]; }
     static FFMPEGNatives getNatives() { return natives; }
     static boolean initSingleton() { return ready; }
 
@@ -357,7 +418,7 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
     public final List<List<String>> getToolLibNames() {
         final List<List<String>> libsList = new ArrayList<List<String>>();
 
-        // 6: util, format, codec, device, avresample, swresample
+        // 6: util, format, codec, device, swresample, swscale
 
         final List<String> avutil = new ArrayList<String>();
         if( FFMPEGMediaPlayer.PREFER_SYSTEM_LIBS ) {
@@ -457,8 +518,32 @@ class FFMPEGDynamicLibraryBundleInfo implements DynamicLibraryBundleInfo  {
         }
         libsList.add(swresample);
 
+        final List<String> swscale = new ArrayList<String>();
+        if( FFMPEGMediaPlayer.PREFER_SYSTEM_LIBS ) {
+            swscale.add("swscale");         // system default
+        } else {
+            swscale.add("internal_swscale");// internal
+        }
+        swscale.add("libswscale.so.7");     // ffmpeg 6.[0-x]
+        swscale.add("libswscale.so.6");     // ffmpeg 5.[0-x]
+        swscale.add("libswscale.so.5");     // ffmpeg 4.[0-x] (Debian-11)
+
+        swscale.add("swscale-7");           // ffmpeg 6.[0-x]
+        swscale.add("swscale-6");           // ffmpeg 5.[0-x]
+        swscale.add("swscale-5");           // ffmpeg 4.[0-x]
+        if( FFMPEGMediaPlayer.PREFER_SYSTEM_LIBS ) {
+            swscale.add("internal_swscale");// internal
+        } else {
+            swscale.add("swscale");         // system default
+        }
+        libsList.add(swscale);
         return libsList;
     }
+    @Override
+    public List<String> getSymbolForToolLibPath() {
+        // 6: util, format, codec, device, swresample, swscale
+        return Arrays.asList("av_free", "av_read_frame", "avcodec_close", "avdevice_register_all", "swr_convert", "swscale_version");
+    }
 
     @Override
     public final List<String> getToolGetProcAddressFuncNameList() {
